@@ -2,8 +2,7 @@
 # dgit
 # Debian::Dgit: functions common to dgit and its helpers and servers
 #
-# Copyright (C)2015-2020,2022-2023 Ian Jackson
-# Copyright (C)2020                Sean Whitton
+# Copyright (C) 2015-2019  Ian Jackson
 #
 #    This program is free software; you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -16,7 +15,7 @@
 #    GNU General Public License for more details.
 #
 #    You should have received a copy of the GNU General Public License
-#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
+#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Debian::Dgit;
 
@@ -550,10 +549,8 @@ sub hashfile ($) {
     return $h->hexdigest();
 }
 
-sub git_rev_parse ($;$) {
-    my ($ref, $cmdprefix) = @_;
-    $cmdprefix //= [ ];
-    return cmdoutput @$cmdprefix, qw(git rev-parse), "$ref~0";
+sub git_rev_parse ($) {
+    return cmdoutput qw(git rev-parse), "$_[0]~0";
 }
 
 sub changedir_git_toplevel () {
@@ -864,12 +861,9 @@ sub parsecontrol {
 }
 
 sub parsechangelog {
-    # parsechangelog [ \@cmdprefix ], @dpkg_changelog_args
     my $c = Dpkg::Control::Hash->new(name => 'parsed changelog');
     my $p = new IO::Handle;
-    my $prefix = [ ];
-    $prefix = shift @_ if ref $_[0];
-    my @cmd = (@$prefix, qw(dpkg-parsechangelog), @_);
+    my @cmd = (qw(dpkg-parsechangelog), @_);
     open $p, '-|', @cmd or confess "$!";
     $c->parse($p);
     $?=0; $!=0; close $p or failedcmd @cmd;
